@@ -35,14 +35,14 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/local/include/python2.7',
     'py_inc_dir':         '/usr/local/include/python2.7',
     'py_lib_dir':         '/usr/local/lib/python2.7/config',
-    'py_version':         0x02070a,
+    'py_version':         0x02070d,
     'qt_framework':       0,
     'sip_bin':            '/usr/local/bin/sip',
     'sip_config_args':    '-b /usr/local/bin -d /usr/local/lib/python2.7/site-packages -e /usr/local/include/python2.7 -v /usr/local/share/sip INCDIR=/usr/local/include LIBDIR=/usr/local/lib CC=cc CXX=c++ CFLAGS=-O2 -pipe   CXXFLAGS=-O2 -pipe  ',
     'sip_inc_dir':        '/usr/local/include/python2.7',
     'sip_mod_dir':        '/usr/local/lib/python2.7/site-packages',
-    'sip_version':        0x041008,
-    'sip_version_str':    '4.16.8',
+    'sip_version':        0x041201,
+    'sip_version_str':    '4.18.1',
     'universal':          ''
 }
 
@@ -129,9 +129,9 @@ _default_macros = {
     'LIBS_WEBKIT':              '',
     'LIBS_WINDOWS':             '',
     'LIBS_X11':                 '-lXext -lX11 -lm',
-    'LINK':                     'g++',
-    'LINK_SHLIB':               'g++',
-    'LINK_SHLIB_CMD':           'g++  	-fPIC  	-o    ',
+    'LINK':                     'c++',
+    'LINK_SHLIB':               'c++',
+    'LINK_SHLIB_CMD':           'c++  	-fPIC  	-o    ',
     'MAKEFILE_GENERATOR':       'UNIX',
     'MKDIR':                    'mkdir -p',
     'RANLIB':                   'ranlib',
